@@ -1683,7 +1683,7 @@ static void
 epub_document_add_mathJax(gchar* containeruri,gchar* documentdir)
 {
     gchar *containerfilename= g_filename_from_uri(containeruri,NULL,NULL);
-    GString *mathjaxdir = g_string_new("/usr/share/javascript/mathjax");
+    GString *mathjaxdir = g_string_new(MATHJAX_DIRECTORY);
 
     gchar *mathjaxref = g_filename_to_uri(mathjaxdir->str,NULL,NULL);
     gchar *nodedata = g_strdup_printf("%s/MathJax.js?config=TeX-AMS-MML_SVG",mathjaxref);
