@@ -61,9 +61,9 @@ cairo_surface_t *ev_document_misc_surface_rotate_and_scale (cairo_surface_t *sur
 void             ev_document_misc_invert_surface (cairo_surface_t *surface);
 void             ev_document_misc_invert_pixbuf  (GdkPixbuf       *pixbuf);
 
-gdouble          ev_document_misc_get_screen_dpi (GdkScreen *screen, GdkMonitor *monitor);
+gdouble          ev_document_misc_get_monitor_dpi (GdkMonitor *monitor);
 
-gchar           *ev_document_misc_format_date (GTime utime);
+gchar           *ev_document_misc_format_date (gint64 utime);
 
 void             ev_document_misc_get_pointer_position (GtkWidget *widget,
 							gint      *x,
